@@ -1,7 +1,7 @@
 import pika, requests, threading, json, time
 from logzero import logger
 from datetime import datetime
-from eventemitter import EventEmitter
+from pymitter import EventEmitter
 
 class AutoSolve:
     SUCCESS = "info"
@@ -154,7 +154,7 @@ class AutoSolve:
             self.log("Connection attempts unsuccessful", self.ERROR)
 
     def send(self, message, route, exchange):
-        message["createdAt"] = datetime.utcnow()
+        message["createdAt"] = str(datetime.utcnow())
         message_string = json.dumps(message)
         byte_string = message_string.encode()
         return self.channel.basic_publish(exchange=exchange,
